| Title: | Datasets from 'KEEL' for it Use in 'RKEEL' |
|---|---|
| Description: | 'KEEL' is a popular Java software for a large number of different knowledge data discovery tasks. Furthermore, 'RKEEL' is a package with a R code layer between R and 'KEEL', for using 'KEEL' in R code. This package includes the datasets from 'KEEL' in .dat format for its use in 'RKEEL' package. For more information about 'KEEL', see <http://www.keel.es/>. |
| Authors: | Jose M. Moyano [aut, cre], Luciano Sanchez Ramos [aut] |
| Maintainer: | Jose M. Moyano <[email protected]> |
| License: | GPL |
| Version: | 1.0.5 |
| Built: | 2026-06-03 10:52:42 UTC |
| Source: | https://github.com/cran/RKEELdata |
Method for knowing the KEELdata datasets path.
getDataPath()getDataPath()
Returns a string with the datasets path.
getDataPath()getDataPath()
Method for knowing which datasets from the KEEL Dataset Repository are availabre at RKEELdata.
getKeelDatasetList()getKeelDatasetList()
Returns a list with the data names.
getKeelDatasetList()getKeelDatasetList()